@@ -49,15 +49,18 @@
 
 #include "ajax.h"
 
+#ifdef AJ_SAVESTATS
 static ajint listNewCnt     = 0;
 static ajint listDelCnt     = 0;
 static ajuint listMaxNum     = 0;
 static ajint listNodeCnt    = 0;
 static ajint listIterNewCnt = 0;
 static ajint listIterDelCnt = 0;
+#endif
 
-
-
+static ajint listFreeNext = 0;
+static ajint listFreeMax = 0;
+static AjPListNode* listFreeSet = NULL;
 
 static AjPList listNew(AjEnum type);
 static void listInsertNode(AjPListNode * pnode, void* x);
@@ -66,7 +69,10 @@ static void listNodesTrace(const AjPListNode node);
 static AjBool listNodeDel(AjPListNode * pnode);
 static void* listNodeItem(const AjPListNode node);
 static void listArrayTrace(void** array);
+static void listFreeSetExpand (void);
 
+   
+  
 
 /* @filesection ajlist *********************************************************
 **
@@ -212,8 +218,10 @@ static AjPList listNew(AjEnum type)
 
     list->Last = listDummyNode(&list->First);
 
+#ifdef AJ_SAVESTATS
     listNodeCnt--;			/* dummy */
     listNewCnt++;
+#endif
 
     return list;
 }
@@ -233,7 +241,11 @@ static void listInsertNode(AjPListNode * pnode, void* x)
 {
     AjPListNode p;
 
-    AJNEW0(p);
+    if(listFreeNext)
+        p = listFreeSet[--listFreeNext];
+    else
+        AJNEW0(p);
+    
     p->Item = x;
     p->Next = (*pnode);
     p->Prev = (*pnode)->Prev;
@@ -242,7 +254,9 @@ static void listInsertNode(AjPListNode * pnode, void* x)
 
     *pnode = p;
 
+#ifdef AJ_SAVESTATS
     listNodeCnt++;
+#endif
 
     return;
 }
@@ -261,9 +275,19 @@ static void listInsertNode(AjPListNode * pnode, void* x)
 
 static AjPListNode listDummyNode(AjPListNode *pnode)
 {
-    AJNEW0(*pnode);
+    if(listFreeNext)
+    {
+        *pnode = listFreeSet[--listFreeNext];
+        (*pnode)->Item = NULL;
+        (*pnode)->Prev = NULL;
+        (*pnode)->Next = NULL;
+    }
+    else
+        AJNEW0(*pnode);
 
+#ifdef AJ_SAVESTATS
     listNodeCnt++;
+#endif
 
     return *pnode;
 }
@@ -311,8 +335,10 @@ void ajListPush(AjPList list, void* x)
     if(!list->Count++)
 	list->Last->Prev = list->First;
 
+#ifdef AJ_SAVESTATS
     if(list->Count > listMaxNum)
 	listMaxNum = list->Count;
+#endif
 
     return;
 }
@@ -354,8 +380,11 @@ void ajListPushAppend(AjPList list, void* x)
     list->Last->Prev = tmp;
 
     list->Count++;
+
+#ifdef AJ_SAVESTATS
     if(list->Count > listMaxNum)
 	listMaxNum = list->Count;
+#endif
 
     return;
 }
@@ -401,15 +430,23 @@ void ajListPushlist(AjPList list, AjPList* Plist)
 	    list->Last = more->Last;
 	}
 
-	AJFREE(list->First);
+        if(listFreeNext >= listFreeMax)
+            listFreeSetExpand();
+        if(listFreeNext >= listFreeMax)
+            AJFREE(list->First);
+        else if(list->First)
+            listFreeSet[listFreeNext++] = list->First;
+        
 	list->First = more->First;
 	list->Count += more->Count;
 	list->First->Prev = NULL;
 	more->First = NULL;
 	more->Count=0;
 
+#ifdef AJ_SAVESTATS
 	if(list->Count > listMaxNum)
 	    listMaxNum = list->Count;
+#endif
     }
 
     ajListFree(Plist);	/* free the list but not the nodes */
@@ -863,7 +900,7 @@ void ajListSortUnique(AjPList list,
 	return;
 
     ajListSort(list, sort1);
-    ajListTrace(list);
+    /*ajListTrace(list);*/
 
     iter = ajListIterNew(list);
     while(!ajListIterDone(iter))
@@ -916,6 +953,32 @@ __deprecated void ajListUnique(AjPList list,
 **
 ******************************************************************************/
 
+/* @funcstatic listFreeSetExpand ***********************************************
+**
+** Expand the list of free nodes
+**
+** @return [void]
+******************************************************************************/
+
+static void listFreeSetExpand (void)
+{
+    ajint newsize;
+    if(!listFreeSet)
+    {
+        listFreeMax = 1024;
+        AJCNEW0(listFreeSet,listFreeMax);
+        return;
+    }
+    if(listFreeMax >= 65536)
+        return;
+    newsize = listFreeMax + listFreeMax;
+    AJCRESIZE0(listFreeSet, listFreeMax, newsize);
+    listFreeMax = newsize;
+    return;
+}
+
+    
+    
 /* @func ajListPop ************************************************************
 **
 ** remove the first node but set pointer to data first.
@@ -928,9 +991,13 @@ __deprecated void ajListUnique(AjPList list,
 
 AjBool ajListPop(AjPList list, void** x)
 {
-    if(!list)
+    if(!list) 
+    {
+        if(x)
+            *x = NULL;
 	return ajFalse;
-
+    }
+    
     if(x)
 	*x = listNodeItem(list->First);
 
@@ -961,7 +1028,12 @@ AjBool ajListPopLast(AjPList list, void** x)
     AjPListNode pthis = NULL;
 
     if(!list)
+    {
+        if(x)
+            *x = NULL;
 	return ajFalse;
+    }
+    
 
     if(!list->Count)
 	return ajFalse;
@@ -975,15 +1047,31 @@ AjBool ajListPopLast(AjPList list, void** x)
     if(list->Count==1)
     {
 	list->Last->Prev = NULL;
-	AJFREE(list->First);
+        if(listFreeNext >= listFreeMax)
+            listFreeSetExpand();
+        if(listFreeNext >= listFreeMax)
+            AJFREE(list->First);
+        else if(list->First)
+            listFreeSet[listFreeNext++] = list->First;
+        
 	list->First = list->Last;
     }
     else
     {
 	pthis->Prev->Next = list->Last;
 	list->Last->Prev = pthis->Prev;
-	AJFREE(pthis);
+        if(listFreeNext >= listFreeMax)
+            listFreeSetExpand();
+        if(listFreeNext >= listFreeMax)
+            AJFREE(pthis);
+        else if(pthis)
+        {
+            listFreeSet[listFreeNext++] = pthis;
+            pthis = NULL;
+        }
+        
     }
+    
 
 
     --list->Count;
@@ -1183,7 +1271,10 @@ AjBool ajListPeekFirst(const AjPList list, void** x)
     if(!list)
 	return ajFalse;
 
-    if(x)
+    if(!list->Count)
+        return ajFalse;
+
+  if(x)
 	*x = listNodeItem(list->First);
 
     return ajTrue;
@@ -1353,10 +1444,13 @@ static void listArrayTrace(void** array)
 **
 ** @fdata [AjPList]
 **
+** @nam3rule Probe Test for memory allocation conflicts
+** @nam4rule ProbeData Test data for memory allocation conflicts
 ** @nam3rule Print Trace contents to standard error
 ** @nam3rule Trace Trace contents to debug file
 **
-** @argrule * list [const AjPList] List
+** @argrule Probe Plist [AjPList const*] Pointer to list
+** @argrule Trace list  [const AjPList]  List
 **
 ** @valrule * [void]
 **
@@ -1366,6 +1460,94 @@ static void listArrayTrace(void** array)
 
 
 
+/* @func ajListProbe ***********************************************************
+**
+** Test list for memory allocation conflicts
+**
+** @param [r] Plist [AjPList const*] List
+** @return [void]
+** @@
+******************************************************************************/
+
+void ajListProbe(AjPList const * Plist)
+{
+    AjPListNode next;
+    AjPListNode *rest;
+    AjPList list;
+
+    if(!Plist)
+	return;
+
+    if(!*Plist)
+	return;
+
+    list = *Plist;
+    rest = &list->First;
+
+    /* don't free the data in the list (we don't know how) */
+    /* just free the nodes */
+    if(list->Count)
+	for( ; (*rest)->Next; *rest = next)
+	{
+	    next = (*rest)->Next;
+	    AJMPROBE(*rest);
+	}
+
+    AJMPROBE(*rest);
+    AJMPROBE(*Plist);
+
+    return;
+}
+
+
+
+
+/* @func ajListProbeData *******************************************************
+**
+** Test list and data for memory allocation conflicts
+**
+** @param [r] Plist [AjPList const*] List
+** @return [void]
+** @@
+******************************************************************************/
+
+void ajListProbeData(AjPList const * Plist)
+{
+    AjPListNode next;
+    AjPListNode *rest;
+    AjPList list;
+
+    if(!Plist)
+	return;
+
+    if(!*Plist)
+	return;
+
+    list = *Plist;
+    rest = &list->First;
+
+
+    /* free the data for each node (just a simple free) */
+    /* as we free the nodes */
+
+    if(list->Count)
+    {
+	for( ; (*rest)->Next; *rest = next)
+	{
+	    AJMPROBE((*rest)->Item);
+	    next = (*rest)->Next;
+	    AJMPROBE(*rest);
+	}
+	AJMPROBE((*rest)->Item);
+    }
+
+    AJMPROBE(*rest);
+    AJMPROBE(*Plist);
+
+    return;
+}
+
+
 /* @func ajListTrace **********************************************************
 **
 ** Traces through a list and validates it
@@ -1499,8 +1681,10 @@ __deprecated void ajListAppend(AjPList list, AjPListNode* morenodes)
     {				/* need to get to the end of the list */
 	more = more->Next;
 	list->Count++;
+#ifdef AJ_SAVESTATS
 	if(list->Count > listMaxNum)
 	    listMaxNum = list->Count;
+#endif
     }
 
     list->Last = more;		/* now we can set the end of the list */
@@ -1576,7 +1760,9 @@ void ajListFree(AjPList* Plist)
     if(!*Plist)
 	return;
 
+#ifdef AJ_SAVESTATS
     listDelCnt++;
+#endif
 
     list = *Plist;
     rest = &list->First;
@@ -1587,10 +1773,27 @@ void ajListFree(AjPList* Plist)
 	for( ; (*rest)->Next; *rest = next)
 	{
 	    next = (*rest)->Next;
-	    AJFREE(*rest);
+            if(listFreeNext >= listFreeMax)
+                listFreeSetExpand();
+            if(listFreeNext >= listFreeMax)
+                AJFREE(*rest);
+            else if(*rest)
+            {
+                listFreeSet[listFreeNext++] = *rest;
+                *rest = NULL;
+            }
 	}
 
-    AJFREE(*rest);
+    if(listFreeNext >= listFreeMax)
+        listFreeSetExpand();
+    if(listFreeNext >= listFreeMax)
+        AJFREE(*rest);
+    else if(*rest)
+    {
+        listFreeSet[listFreeNext++] = *rest;
+        *rest = NULL;
+    }
+    
     AJFREE(*Plist);
 
     return;
@@ -1622,7 +1825,9 @@ void ajListFreeData(AjPList* Plist)
     if(!*Plist)
 	return;
 
+#ifdef AJ_SAVESTATS
     listDelCnt++;
+#endif
 
     list = *Plist;
     rest = &list->First;
@@ -1631,15 +1836,35 @@ void ajListFreeData(AjPList* Plist)
     /* free the data for each node (just a simple free) */
     /* as we free the nodes */
 
-    if(!list->Count)
+    if(list->Count)
+    {
 	for( ; (*rest)->Next; *rest = next)
 	{
 	    AJFREE((*rest)->Item);
 	    next = (*rest)->Next;
-	    AJFREE(*rest);
-	}
+            if(listFreeNext >= listFreeMax)
+                listFreeSetExpand();
+            if(listFreeNext >= listFreeMax)
+                AJFREE(*rest);
+            else if(*rest)
+            {
+                listFreeSet[listFreeNext++] = *rest;
+                *rest = NULL;
+            }
+        }
+	AJFREE((*rest)->Item);
+    }
+
+    if(listFreeNext >= listFreeMax)
+        listFreeSetExpand();
+    if(listFreeNext >= listFreeMax)
+        AJFREE(*rest);
+    else if(*rest)
+    {
+        listFreeSet[listFreeNext++] = *rest;
+        *rest = NULL;
+    }
 
-    AJFREE(*rest);
     AJFREE(*Plist);
 
     return;
@@ -1662,7 +1887,9 @@ __deprecated void ajListDel(AjPList* Plist)
     if(!*Plist)
 	return;
 
+#ifdef AJ_SAVESTATS
     listDelCnt++;
+#endif
 
     list = *Plist;
     rest = &list->First;
@@ -1671,10 +1898,27 @@ __deprecated void ajListDel(AjPList* Plist)
 	for( ; (*rest)->Next; *rest = next)
 	{
 	    next = (*rest)->Next;
-	    AJFREE(*rest);
-	}
+            if(listFreeNext >= listFreeMax)
+                listFreeSetExpand();
+            if(listFreeNext >= listFreeMax)
+                AJFREE(*rest);
+            else if(*rest)
+            {
+                listFreeSet[listFreeNext++] = *rest;
+                *rest = NULL;
+            }
+        }
+
+    if(listFreeNext >= listFreeMax)
+        listFreeSetExpand();
+    if(listFreeNext >= listFreeMax)
+        AJFREE(*rest);
+    else if(*rest)
+    {
+        listFreeSet[listFreeNext++] = *rest;
+        *rest = NULL;
+    }
 
-    AJFREE(*rest);
     AJFREE(*Plist);
 
     return;
@@ -1685,7 +1929,7 @@ __deprecated void ajListDel(AjPList* Plist)
 
 /* @funcstatic listNodeDel ****************************************************
 **
-** Remove a first node from the list.
+** Remove a node from the list.
 **
 ** @param [d] pnode  [AjPListNode*] Current node.
 ** @return [AjBool] ajTrue on success.
@@ -1705,7 +1949,14 @@ static AjBool listNodeDel(AjPListNode * pnode)
     tmp = node->Prev;
     node = node->Next;
     node->Prev = tmp;
-    AJFREE(*pnode);
+
+    if(listFreeNext >= listFreeMax)
+        listFreeSetExpand();
+    if(listFreeNext >= listFreeMax)
+        AJFREE(*pnode);
+    else if(*pnode)
+        listFreeSet[listFreeNext++] = *pnode;
+ 
     *pnode = node;
 
     return ajTrue;
@@ -1776,11 +2027,25 @@ void ajListUnused(void** array)
 
 void ajListExit(void)
 {
+    ajint i;
+
+#ifdef AJ_SAVESTATS
     ajDebug("List usage : %d opened, %d closed, %d maxsize %d nodes\n",
 	     listNewCnt, listDelCnt, listMaxNum, listNodeCnt);
     ajDebug("List iterator usage : %d opened, %d closed\n",
 	     listIterNewCnt, listIterDelCnt);
+#endif
+    if(listFreeNext)
+        for(i=0;i<listFreeNext;i++)
+            AJFREE(listFreeSet[i]);
 
+            
+    if(listFreeSet) 
+        AJFREE(listFreeSet);
+
+    listFreeNext = 0;
+    listFreeMax = 0;
+    
     return;
 }
 
@@ -1841,10 +2106,11 @@ AjIList ajListIterNew(AjPList list)
     iter->Head = list;
     iter->Back = ajFalse;
     iter->Here = list->First;
-    iter->Orig = list->First;
     iter->Modify = ajTrue;
 
+#ifdef AJ_SAVESTATS
     listIterNewCnt++;
+#endif
 
     return iter;
 }
@@ -1890,7 +2156,9 @@ AjIList ajListIterNewBack(AjPList list)
     iter->Here = tmp->Next;
     iter->Modify = ajTrue;
 
+#ifdef AJ_SAVESTATS
     listIterNewCnt++;
+#endif
 
     return iter;
 }
@@ -1927,10 +2195,11 @@ AjIList ajListIterNewread(const AjPList list)
     iter->ReadHead = list;
     iter->Back = ajFalse;
     iter->Here = list->First;
-    iter->Orig = list->First;
     iter->Modify = ajFalse;
 
+#ifdef AJ_SAVESTATS
     listIterNewCnt++;
+#endif
 
     return iter;
 }
@@ -1976,7 +2245,9 @@ AjIList ajListIterNewreadBack(const AjPList list)
     iter->Here = tmp->Next;
     iter->Modify = ajFalse;
 
+#ifdef AJ_SAVESTATS
     listIterNewCnt++;
+#endif
 
     return iter;
 }
@@ -2120,7 +2391,9 @@ void ajListIterDel(AjIList* iter)
 {
     AJFREE(*iter);
 
+#ifdef AJ_SAVESTATS
     listIterDelCnt++;
+#endif
 
     return;
 }
@@ -2199,6 +2472,7 @@ void* ajListIterGet(AjIList iter)
     return ret;
 }
 
+
 /* @obsolete ajListIterNext
 ** @rename ajListIterGet
 */
@@ -2261,6 +2535,7 @@ __deprecated void* ajListIterBackNext(AjIList iter)
 **
 ** @nam4rule   Insert  Insert a new value at iterator position
 ** @nam4rule   Remove  Remove value at iterator position
+** @nam4rule   Rewind  Rewind list to start
 **
 ** @argrule * iter [AjIList] String iterator
 ** @argrule Insert x [void*] Value
@@ -2318,8 +2593,10 @@ void ajListIterInsert(AjIList iter, void* x)
     }
 
     list->Count++;
+#ifdef AJ_SAVESTATS
     if(list->Count > listMaxNum)
 	listMaxNum = list->Count;
+#endif
 
     /*ajListTrace(list);*/
     /*ajListIterTrace(iter);*/
@@ -2399,6 +2676,44 @@ __deprecated void ajListRemove(AjIList iter)
     return;
 }
 
+/* @func ajListIterRewind ******************************************************
+**
+** Resets iterator to start position
+**
+** @param [u] iter [AjIList] List iterator.
+** @return [void]
+** @@
+******************************************************************************/
+
+void ajListIterRewind(AjIList iter)
+{
+    AjPListNode node = NULL;
+    AjPListNode tmp  = NULL;
+    const AjPList list;
+
+    if(!iter)
+        return;
+
+    if(iter->Modify)
+        list = iter->Head;
+    else
+        list = iter->ReadHead;
+
+    if(iter->Back)
+    {
+        for(node=list->First; node->Next; node = node->Next)
+            tmp = node;
+        iter->Here = tmp->Next;
+    }
+    else
+    {
+        iter->Here = list->First;
+    }
+    
+    return;
+}
+
+
 /* @section Trace functions ***************************************************
 **
 ** @fdata [AjIList]
@@ -2709,7 +3024,7 @@ __deprecated void ajListstrPushList(AjPList list, AjPList* Plist)
 ** @@
 ******************************************************************************/
 
-void ajListstrMap(AjPList list, void (*apply) (AjPStr* x, void* cl), void* cl)
+void ajListstrMap(AjPList list, void apply(AjPStr* x, void* cl), void* cl)
 {
     AjPListNode rest;
 
@@ -2820,16 +3135,32 @@ AjBool ajListstrPopLast(AjPList list, AjPStr *Pstr)
     if(list->Count==1)
     {
 	list->Last->Prev = NULL;
-	AJFREE(list->First);
+        if(listFreeNext >= listFreeMax)
+            listFreeSetExpand();
+        if(listFreeNext >= listFreeMax)
+            AJFREE(list->First);
+        else if(list->First)
+            listFreeSet[listFreeNext++] = list->First;
+        
 	list->First = list->Last;
     }
     else
     {
 	pthis->Prev->Next = list->Last;
 	list->Last->Prev = pthis->Prev;
-	AJFREE(pthis);
+        if(listFreeNext >= listFreeMax)
+            listFreeSetExpand();
+        if(listFreeNext >= listFreeMax)
+            AJFREE(pthis);
+        else if(pthis)
+        {
+            listFreeSet[listFreeNext++] = pthis;
+            pthis = NULL;
+        }
     }
 
+    
+
 
     --list->Count;
     return ajTrue;
@@ -3288,7 +3619,9 @@ void ajListstrFreeData(AjPList* Plist)
     if(!*Plist)
 	return;
 
+#ifdef AJ_SAVESTATS
     listDelCnt++;
+#endif
 
     list = *Plist;
     rest = &list->First;
@@ -3300,13 +3633,30 @@ void ajListstrFreeData(AjPList* Plist)
 	{
 	    next = (*rest)->Next;
 	    ajStrDel((AjPStr*) &(*rest)->Item);
-	    AJFREE(*rest);
+            if(listFreeNext >= listFreeMax)
+                listFreeSetExpand();
+            if(listFreeNext >= listFreeMax)
+                AJFREE(*rest);
+            else if(*rest)
+            {
+                listFreeSet[listFreeNext++] = *rest;
+                *rest=NULL;
+            }
 	}
 	ajStrDel((AjPStr*) &(*rest)->Item);
     }
 
 
-    AJFREE(*rest);
+    if(listFreeNext >= listFreeMax)
+        listFreeSetExpand();
+    if(listFreeNext >= listFreeMax)
+        AJFREE(*rest);
+    else if(*rest)
+    {
+        listFreeSet[listFreeNext++] = *rest;
+        *rest = NULL;
+    }
+    
     AJFREE(*Plist);
 
     return;
@@ -3328,6 +3678,97 @@ void ajListstrFreeData(AjPList* Plist)
 
 
 
+/* @section stepping **********************************************************
+**
+** @fdata [AjIList]
+**
+** @nam4rule   Get      Next value.
+** @nam5rule   GetBack  Next value in reverse direction
+**
+** @argrule * iter [AjIList] String iterator
+**
+** @valrule * [AjPStr] Value
+**
+** @fcategory modify
+*/
+
+
+/* @func ajListstrIterGet *****************************************************
+**
+** Returns next item using iterator, or steps off the end.
+**
+** @param [u] iter [AjIList] List iterator.
+** @return [AjPStr] Data item returned.
+** @@
+******************************************************************************/
+
+AjPStr ajListstrIterGet(AjIList iter)
+{
+    AjPListNode p;
+    void *ret;
+
+    if(!iter)
+	return NULL;
+
+    p = iter->Here;
+
+    if(!iter->Back)
+    {
+	if(!p->Next)
+	    return NULL;
+	ret = p->Item;
+	iter->Here = p->Next;
+    }
+    else
+    {
+	if(!p->Next->Next || !p->Next->Next->Next)
+	  return NULL;
+	iter->Back = ajFalse;
+	ret = p->Next->Item;
+	iter->Here = p->Next->Next;
+    }
+
+    return (AjPStr) ret;
+}
+
+/* @func ajListstrIterGetBack *************************************************
+**
+** Returns next item using back iterator.
+**
+** @param [u] iter [AjIList] List iterator.
+** @return [AjPStr] Data item returned.
+** @@
+******************************************************************************/
+
+AjPStr ajListstrIterGetBack(AjIList iter)
+{
+    AjPListNode p;
+    void* ret;
+
+    if(!iter)
+	return NULL;
+
+    p = iter->Here;
+
+    if(!p->Prev)
+      return NULL;
+
+    if(!iter->Back)
+    {
+	ret = p->Prev->Prev->Item;
+	iter->Here = p->Prev->Prev;
+	iter->Back = ajTrue;
+    }
+    else
+    {
+	ret = p->Prev->Item;
+	iter->Here = p->Prev;
+    }
+
+    return (AjPStr) ret;
+}
+
+
 /* @section modifiers **********************************************************
 **
 ** @fdata [AjIList]
@@ -3397,8 +3838,10 @@ void ajListstrIterInsert(AjIList iter, AjPStr str)
     }
 
     list->Count++;
+#ifdef AJ_SAVESTATS
     if(list->Count > listMaxNum)
 	listMaxNum = list->Count;
+#endif
 
     ajListstrTrace(list);
     ajListstrIterTrace(iter);
@@ -3521,7 +3964,3 @@ void ajListstrIterTrace(const AjIList iter)
 
     return;
 }
-
-
-
-
