@@ -152,29 +152,29 @@ int main(int argc, char **argv)
     uppercase      = ajAcdGetRange("uppercase");
     highlight      = ajAcdGetRange("highlight");
     annotation     = ajAcdGetRange("annotation");
-    threeletter    = ajAcdGetBool("threeletter");
-    numberseq      = ajAcdGetBool("number");
+    threeletter    = ajAcdGetBoolean("threeletter");
+    numberseq      = ajAcdGetBoolean("number");
     width          = ajAcdGetInt("width");
     length         = ajAcdGetInt("length");
     margin         = ajAcdGetInt("margin");
-    nameseq        = ajAcdGetBool("name");
-    description    = ajAcdGetBool("description");
+    nameseq        = ajAcdGetBoolean("name");
+    description    = ajAcdGetBoolean("description");
     offset         = ajAcdGetInt("offset");
-    html           = ajAcdGetBool("html");
+    html           = ajAcdGetBoolean("html");
     orfminsize     = ajAcdGetInt("orfminsize");
-    flat           = ajAcdGetBool("flatreformat");
+    flat           = ajAcdGetBoolean("flatreformat");
 
     /*  restriction enzyme stuff */
     mincuts    = ajAcdGetInt("mincuts");
     maxcuts    = ajAcdGetInt("maxcuts");
     sitelen    = ajAcdGetInt("sitelen");
-    single     = ajAcdGetBool("single");
-    blunt      = ajAcdGetBool("blunt");
-    sticky     = ajAcdGetBool("sticky");
-    ambiguity  = ajAcdGetBool("ambiguity");
-    plasmid    = ajAcdGetBool("plasmid");
-    commercial = ajAcdGetBool("commercial");
-    limit      = ajAcdGetBool("limit");
+    single     = ajAcdGetBoolean("single");
+    blunt      = ajAcdGetBoolean("blunt");
+    sticky     = ajAcdGetBoolean("sticky");
+    ambiguity  = ajAcdGetBoolean("ambiguity");
+    plasmid    = ajAcdGetBoolean("plasmid");
+    commercial = ajAcdGetBoolean("commercial");
+    limit      = ajAcdGetBoolean("limit");
     enzymes    = ajAcdGetString("enzymes");
 
     /* feature filter criteria */
@@ -185,7 +185,7 @@ int main(int argc, char **argv)
     maxscore    = ajAcdGetFloat("maxscore");
     matchtag    = ajAcdGetString("matchtag");
     matchvalue  = ajAcdGetString("matchvalue");
-    stricttags  = ajAcdGetBool("stricttags");
+    stricttags  = ajAcdGetBoolean("stricttags");
 
 
     format = ajStrNew();
@@ -291,14 +291,14 @@ int main(int argc, char **argv)
 	    if(single)
 		maxcuts = mincuts = 1;
 	    retable = ajTablestrNewLen(EQUGUESS);
-	    ajFileDataNewC(ENZDATA, &enzfile);
+	    enzfile = ajDatafileNewInNameC(ENZDATA);
 
 	    if(!enzfile)
 		ajFatal("Cannot locate enzyme file. Run REBASEEXTRACT");
 
 	    if(limit)
 	    {
-		ajFileDataNewC(EQUDATA,&equfile);
+		equfile = ajDatafileNewInNameC(EQUDATA);
 		if(!equfile)
 		    limit = ajFalse;
 		else
@@ -508,7 +508,7 @@ static void showseq_read_equiv(AjPFile equfile, AjPTable table)
 
     line = ajStrNew();
 
-    while(ajFileReadLine(equfile,&line))
+    while(ajReadlineTrim(equfile,&line))
     {
         p = ajStrGetPtr(line);
 
@@ -548,14 +548,14 @@ static void showseq_read_file_of_enzyme_names(AjPStr *enzymes)
     if(ajStrFindC(*enzymes, "@") == 0)
     {
 	ajStrTrimC(enzymes, "@");	/* remove the @ */
-	file = ajFileNewIn(*enzymes);
+	file = ajFileNewInNameS(*enzymes);
 	if(file == NULL)
 	    ajFatal("Cannot open the file of enzyme names: '%S'", enzymes);
 
 	/* blank off the enzyme file name and replace with the enzyme names */
 	ajStrSetClear(enzymes);
 	line = ajStrNew();
-	while(ajFileReadLine(file, &line))
+	while(ajReadlineTrim(file, &line))
 	{
 	    p = ajStrGetPtr(line);
 
