@@ -261,7 +261,7 @@ sub secttest($$) {
     elsif ($sect =~ /Miscellaneous$/) {$stype = "misc"}
     if ($stype eq "") {return $stype}
     if ($stype ne $ctype) {
-	print "bad category '$ctype' in section '$sect'\n";
+	print "bad category '$ctype' (expected '$stype') in section '$sect'\n";
     }
     return $stype;
 }
@@ -589,6 +589,8 @@ $filestrstatic = "<p><b>Datatypes:</b> ";
 
 $ftable = "";
 
+$lastfname = "";
+
 ### cppreserved is a list of C++ reserved words not to be used as param names.
 ### test is whether to test the return etc.
 ### body is whether to print the body code
